#!/bin/bash

# This script is used for installing rpm public key and registering repository
# in package manager.

debug() {
  #Uncomment below to see some diagnostic messages
  logger $*
}

install_key() {
  rpm -q gpg-pubkey-f6d61d45-5565d6e9 >/dev/null 2>&1
  if [ "$?" -eq "0" ]; then
    debug "Key installed already"
    return 0
  fi

  local TMPFILE=$(mktemp -t opera-tmp-key.XXXXXX)

  cat >"$TMPFILE" <<ENDKEY
-----BEGIN PGP PUBLIC KEY BLOCK-----
Version: GnuPG v1
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=nJ7H
-----END PGP PUBLIC KEY BLOCK-----
ENDKEY

  rpm --import "$TMPFILE" >/dev/null 2>&1
  local import_result="$?"

  rm "$TMPFILE"

  if [ "$import_result" != "0" ]; then
    debug "Failed key installation"
    return 1
  fi

  debug "Key installation success"
}

install_repo() {
  local RELEASE
  local PKGMANAGER
  LSB_RELEASE="$(which lsb_release 2> /dev/null)"

  if [ -x "$LSB_RELEASE" ]; then
    RELEASE=$(lsb_release -i 2> /dev/null | sed 's/:\t/:/' | cut -d ':' -f 2-)
    case $RELEASE in
      "Fedora")
        PKGMANAGER=yum
        ;;
      "SUSE LINUX")
        PKGMANAGER=zypper
        ;;
    esac
  fi

  if [ -z "$PKGMANAGER" ]; then
    if [ -f "/etc/fedora-release" ] || [ -f "/etc/redhat-release" ]; then
      PKGMANAGER=yum
    elif [ -f "/etc/SuSE-release" ]; then
      PKGMANAGER=zypper
    fi
  fi

  case $PKGMANAGER in
  "yum")
    if [ -e "/etc/yum.repos.d/opera.repo" ]; then
      debug "Opera yum repo exists already"
    else
      cat >"/etc/yum.repos.d/opera.repo" <<ENDREPO
[opera]
name=Opera packages
type=rpm-md
baseurl=https://rpm.opera.com/rpm
gpgcheck=1
gpgkey=https://rpm.opera.com/rpmrepo.key
enabled=1
ENDREPO
    if [ "$?" != "0" ]; then
      debug "Yum repo installation problem"
      exit 1
    fi
    debug "Yum repo installed successfully"
    fi
    ;;
  "zypper")
    if [ -e "/etc/zypp/repos.d/opera.repo" ]; then
      debug "Opera zypper repo exists already"
    else
      cat >"/etc/zypp/repos.d/opera.repo" <<ENDREPO
[opera]
name=Opera packages
type=rpm-md
baseurl=https://rpm.opera.com/rpm
gpgcheck=1
gpgkey=https://rpm.opera.com/rpmrepo.key
enabled=1
autorefresh=1
keeppackages=0
ENDREPO
    if [ "$?" != "0" ]; then
      debug "Zypper repo installation problem"
      exit 1
    fi
    debug "Zypper repo installed successfully"
    fi
    ;;
  else)
    debug "Unsupported package manager";
    ;;
  esac
}


install_key && install_repo
exit $?